/****************************************************************************
 *                                                                          *
 * File: main.qml                                                           *
 * Desc: QRView extension demo app                                          *
 * (c) 2012-2013, CBD BC, Oleg Bolshakov, http://www.kpda.ru                *
 *                                                                          *
 ****************************************************************************/

import QtQuick 1.0
import com.kpda.qrview 1.0

Item {
	id: main
    width: 1024
    height: 600

    Image {
        anchors.fill: parent
        fillMode: Image.Tile
        source: "img/background.jpg"
    }

    Rectangle {
        id: qrItem
        width: qrSymbol.width + anchors.margins * 2
        height: width
        anchors.horizontalCenter: qrData.horizontalCenter
        anchors.top: qrData.bottom
        anchors.margins: 20
        color: "white"

        QRView {
            id: qrSymbol
            anchors.centerIn: qrItem
            version: 0 + qrVersion.text
            brushWidth: 0 + qrBrush.text == 0 ? 1 : 0 + qrBrush.text
            text: qrText.text
        }
    }

    Rectangle {
        id: qrData
        width: qrDataContent.width + anchors.margins * 2
        height: qrDataContent.height + anchors.margins * 2
        anchors.horizontalCenter: main.horizontalCenter
        anchors.top: main.top
        anchors.margins: 20
        color: "gray"
        radius: 10
        border.color: "white"
        border.width: 3
    }

	Column {
        id: qrDataContent
        anchors.centerIn: qrData
        anchors.margins: 20

        Row {
            Text { text: "Text: "; font.bold: true }
            TextInput
            {
                id: qrText
                maximumLength: 70
                selectByMouse: true
                text: "http://www.kpda.ru"
            }
        }
        Row {
            Text { text: "Version (0-20): "; font.bold: true }
            TextInput
            {
                id: qrVersion
                maximumLength: 2
                validator: IntValidator{bottom: 1; top: 20}
                selectByMouse: true
                text: "3"
            }
        }
        Row {
            Text { text: "Dot size (1-10 px): "; font.bold: true }
            TextInput {
                id: qrBrush
                maximumLength: 2
                validator: IntValidator{bottom: 1; top: 10}
                selectByMouse: true
                text: "5"
            }
        }
        Row {
            Rectangle {
                width: qrDataContent.width
                height: 1
                color: "black"
            }
        }
        Row {
            Text { text: "QR symbol: "; font.bold: true }
            Text { text: "version " + qrSymbol.paintedVersion }
        }
        Row {
            Text { text: "Content: "; font.bold: true }
            Text { text: qrSymbol.text }
        }
    }

}
